## 1.0.3
**ADDED**
* Details API [PUT, PATCH, DELETE]
* Allowed method choosing option
* Only view class or only serializer class can override
* Added support for view class or viewset or generic view

**UPDATED**
* Nothing

**BUG FIXED**
* Fixed queryset override issue
* Fixed queryset caching issue


## 0.1.2
**ADDED**
* Nothing

**UPDATED**
* Nothing

**BUG FIXED**
* pip install failed issue
* twine upload issue

## 0.1.1
**ADDED**
* Added utility classes for support 
* Added example app for local testing(Not added in package)

**UPDATED**
* Updated directory structure of app
* Seperated mixins

**BUG FIXED**
* Fixed wrong queryset bug
* Added loop iteration improvements

## 0.0.1
**ADDED**
* Model Based api writing
* Ability to override Serializer, View class, queryset
* Work on proxy model

**BUG FIXED**
* Nothing as it's initial release
